nuflux
======

nuflux is a library for evaluating atmospheric neutrino flux models.

.. toctree::
  :maxdepth: 1
  :caption: Contents:


  overview
  installation
  usage
  evaluation
  fluxes
  development
  pythonapi
  cppapi
  about
